@@ -1,3 +1,5 @@
+from conan.api.input import UserInput
+from conan.api.model import Remote
 from conan.api.output import cli_out_write
 from conan.cli.command import conan_command, conan_subcommand, OnceArgument
 from conan.cli.formatters import default_json_formatter
@@ -69,11 +71,26 @@ def config_install_pkg(conan_api, parser, subparser, *args):
                            help="Filename of the updated lockfile")
     subparser.add_argument("-f", "--force", action='store_true',
                            help="Force the re-installation of configuration")
+    subparser.add_argument("--url", action=OnceArgument,
+                           help="(Experimental) Provide Conan repository URL "
+                                "(for first install without remotes)")
+    subparser.add_argument("-pr", "--profile", help="Profile to install config")
+    subparser.add_argument("-s", "--settings", action="append", help="Settings to install config")
+    subparser.add_argument("-o", "--options", action="append", help="Options to install config")
     args = parser.parse_args(*args)
 
     lockfile = conan_api.lockfile.get_lockfile(lockfile=args.lockfile,
                                                partial=args.lockfile_partial)
-    config_pref = conan_api.config.install_pkg(args.item, lockfile=lockfile, force=args.force)
+
+    try:
+        default_profile = args.profile or conan_api.profiles.get_default_build()
+    except ConanException:  # it can fail if the default profile doesn't exist yet
+        default_profile = None
+    profiles = [default_profile] if default_profile else []
+    profile = conan_api.profiles.get_profile(profiles, args.settings, args.options)
+    remotes = [Remote("_tmp_conan_config", url=args.url)] if args.url else None
+    config_pref = conan_api.config.install_pkg(args.item, lockfile=lockfile, force=args.force,
+                                               remotes=remotes, profile=profile)
     lockfile = conan_api.lockfile.add_lockfile(lockfile, config_requires=[config_pref.ref])
     conan_api.lockfile.save_lockfile(lockfile, args.lockfile_out)
 
@@ -97,8 +114,14 @@ def config_list(conan_api, parser, subparser, *args):
     """
     Show all the Conan available configurations: core and tools.
     """
-    parser.parse_args(*args)
-    return conan_api.config.builtin_confs
+    subparser.add_argument('pattern', nargs="?",
+                           help="Filter configuration items that matches this pattern")
+    args = parser.parse_args(*args)
+    confs = conan_api.config.builtin_confs
+    if args.pattern:
+        p = args.pattern.lower()
+        confs = {k: v for k, v in confs.items() if p in k.lower() or p in v.lower()}
+    return confs
 
 
 @conan_subcommand(formatters={"text": list_text_formatter, "json": default_json_formatter})
@@ -110,3 +133,12 @@ def config_show(conan_api, parser, subparser, *args):
     args = parser.parse_args(*args)
 
     return conan_api.config.show(args.pattern)
+
+
+@conan_subcommand()
+def config_clean(conan_api, parser, subparser, *args):
+    """
+    (Experimental) Clean the configuration files in the Conan home folder, while keeping installed packages
+    """
+    parser.parse_args(*args)
+    conan_api.config.clean()
